AttributionData class

Representation of attribution data

Constructors

AttributionData({AttributionOffer? offer, AttributionPublisher? publisher, Ids? ids, PostbackDecision? decision, GoogleInstallReferrerData? googleInstallReferrer})
Class constructor
AttributionData.fromJson(Map<String, dynamic> json)
Creates an AttributionData object from a JSON map.
factory

Properties

decision ↔ PostbackDecision?
getter/setter pair
googleInstallReferrer ↔ GoogleInstallReferrerData?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ids ↔ Ids?
getter/setter pair
offer ↔ AttributionOffer?
getter/setter pair
publisher ↔ AttributionPublisher?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts an AttributionData object to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited